@@ -39,7 +39,6 @@ func init() {
 
 	macosCmd.Flags().BoolP("list", "l", false, "Show latest macOS installers")
 	macosCmd.Flags().StringP("work-dir", "w", "", "macOS installer creator working directory")
-	macosCmd.Flags().Bool("ignore", false, "Do NOT verify pkg digests")
 	macosCmd.Flags().BoolP("assistant", "a", false, "Only download the InstallAssistant.pkg")
 	macosCmd.Flags().Bool("latest", false, "Download latest macOS installer")
 	// macosCmd.Flags().BoolP("kernel", "k", false, "Extract kernelcache from remote installer")
@@ -52,7 +51,6 @@ func init() {
 	})
 	viper.BindPFlag("download.macos.list", macosCmd.Flags().Lookup("list"))
 	viper.BindPFlag("download.macos.work-dir", macosCmd.Flags().Lookup("work-dir"))
-	viper.BindPFlag("download.macos.ignore", macosCmd.Flags().Lookup("ignore"))
 	viper.BindPFlag("download.macos.assistant", macosCmd.Flags().Lookup("assistant"))
 	viper.BindPFlag("download.macos.latest", macosCmd.Flags().Lookup("latest"))
 	// viper.BindPFlag("download.macos.kernel", macosCmd.Flags().Lookup("kernel"))
@@ -96,7 +94,6 @@ var macosCmd = &cobra.Command{
 		// flags
 		showInstallers := viper.GetBool("download.macos.list")
 		workDir := viper.GetString("download.macos.work-dir")
-		ignoreSha1 := viper.GetBool("download.macos.ignore")
 		assistantOnly := viper.GetBool("download.macos.assistant")
 		latest := viper.GetBool("download.macos.latest")
 		// remoteKernel := viper.GetString("download.macos.kernel")
@@ -195,7 +192,7 @@ var macosCmd = &cobra.Command{
 
 		if cont {
 			for _, prod := range prods {
-				if err := prod.DownloadInstaller(workDir, proxy, insecure, skipAll, resumeAll, restartAll, ignoreSha1, assistantOnly); err != nil {
+				if err := prod.DownloadInstaller(workDir, proxy, insecure, skipAll, resumeAll, restartAll, assistantOnly); err != nil {
 					return err
 				}
 			}
