@@ -14,6 +14,7 @@ import (
 	"github.com/blacktop/go-apfs/pkg/disk/dmg"
 	"github.com/blacktop/go-apfs/pkg/disk/hfsplus"
 	"github.com/blacktop/ipsw/pkg/bundle"
+	"github.com/blacktop/ipsw/pkg/ftab"
 	"github.com/blacktop/ipsw/pkg/img3"
 	"github.com/blacktop/ipsw/pkg/img4"
 )
@@ -54,7 +55,7 @@ func IsMachOData(dat []byte) (bool, error) {
 	case Magic32, Magic64, MagicFatBE, MagicFatLE:
 		return true, nil
 	default:
-		return false, fmt.Errorf("not a macho file")
+		return false, nil
 	}
 }
 
@@ -213,6 +214,13 @@ func IsDMG(filePath string) (bool, error) {
 		return false, fmt.Errorf("failed to open file %s: %w", filePath, err)
 	}
 	defer f.Close()
+	var encHdr dmg.EncryptionHeader
+	if err := binary.Read(f, binary.BigEndian, &encHdr); err != nil {
+		return false, fmt.Errorf("failed to read DMG encryption header: %v", err)
+	}
+	if string(encHdr.Magic[:]) == dmg.EncryptedMagic {
+		return true, nil
+	}
 	if _, err := f.Seek(int64(-binary.Size(dmg.UDIFResourceFile{})), io.SeekEnd); err != nil {
 		return false, fmt.Errorf("failed to seek to DMG footer: %v", err)
 	}
@@ -311,6 +319,25 @@ func IsPBZXData(r io.Reader) (bool, error) {
 	}
 }
 
+func IsFTAB(filename string) (bool, error) {
+	f, err := os.Open(filename)
+	if err != nil {
+		return false, fmt.Errorf("failed to open file %s: %w", filename, err)
+	}
+	defer f.Close()
+	if _, err := f.Seek(32, io.SeekStart); err != nil {
+		return false, fmt.Errorf("failed to seek to FTAB magic: %w", err)
+	}
+	var magic uint64
+	if err := binary.Read(f, binary.LittleEndian, &magic); err != nil {
+		return false, fmt.Errorf("failed to read magic: %w", err)
+	}
+	if magic == ftab.FtabMagic {
+		return true, nil
+	}
+	return false, nil
+}
+
 func IsAA(filePath string) (bool, error) {
 	f, err := os.Open(filePath)
 	if err != nil {
